/*
 * Copyright 2017-2020, Schlumberger
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opengroup.osdu.register.provider.gcp.ddms.datastore;

import com.google.cloud.datastore.Datastore;
import org.apache.commons.lang3.StringUtils;
import org.opengroup.osdu.core.common.model.http.DpsHeaders;
import org.opengroup.osdu.core.gcp.multitenancy.DatastoreFactory;
import org.opengroup.osdu.core.gcp.multitenancy.IDatastoreFactory;
import org.opengroup.osdu.core.gcp.multitenancy.TenantFactory;
import org.opengroup.osdu.core.common.model.http.AppException;
import org.springframework.stereotype.Component;

import java.util.HashMap;
import java.util.Map;

@Component
public class DatastoreMultiTenantAccess {

    private final IDatastoreFactory factory;

    private final Map<String, Datastore> tenantRepositories = new HashMap<>();

    public DatastoreMultiTenantAccess() {
        this(new DatastoreFactory(new TenantFactory()));
    }

    DatastoreMultiTenantAccess(IDatastoreFactory factory) {
        this.factory = factory;
    }

    public Datastore get(String tenantName) {
        if (StringUtils.isBlank(tenantName))
            throw invalidTenantGivenException(tenantName);
        if (!tenantRepositories.containsKey(tenantName)) {
            addRepository(tenantName);
        }
        return tenantRepositories.get(tenantName);
    }

    private void addRepository(String tenantName) {
        Datastore ds = factory.getDatastore(tenantName, tenantName);
        if (ds == null)
            throw invalidTenantGivenException(tenantName);
        tenantRepositories.put(tenantName, ds);
    }

    private AppException invalidTenantGivenException(String tenantName) {
        return new AppException(403, "Forbidden", String.format("You do not have access to the %s value given %s",
                DpsHeaders.DATA_PARTITION_ID, tenantName));
    }
}
