package org.opengroup.osdu.register.middleware;

import org.apache.http.HttpStatus;
import org.opengroup.osdu.core.common.http.ResponseHeaders;
import org.opengroup.osdu.core.common.model.http.DpsHeaders;
import org.opengroup.osdu.register.utils.AppServiceConfig;
import org.opengroup.osdu.register.utils.ServiceRequestInfo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import javax.servlet.*;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.util.List;
import java.util.Map;

@Component
public class RegisterFilter implements Filter {

    private static final String OPTIONS_STRING = "OPTIONS";

    @Autowired
    private DpsHeaders headers;
    @Autowired
    private ServiceRequestInfo requestInfo;
    @Autowired
    private AppServiceConfig serviceConfig;

    @Override
    public void init(FilterConfig filterConfig) {
        //do nothing
    }

    @Override
    public void doFilter(ServletRequest request, ServletResponse response, FilterChain chain)
            throws IOException, ServletException {

        HttpServletRequest httpRequest = (HttpServletRequest) request;
        HttpServletResponse httpResponse = (HttpServletResponse) response;

        this.headers.addCorrelationIdIfMissing();

        Map<String, List<Object>> standardHeaders = ResponseHeaders.STANDARD_RESPONSE_HEADERS;
        for (Map.Entry<String, List<Object>> header : standardHeaders.entrySet()) {
            httpResponse.addHeader(header.getKey(), header.getValue().toString());
        }
        httpResponse.addHeader(DpsHeaders.CORRELATION_ID, this.headers.getCorrelationId());

        if (!validateIsHttps(httpResponse)) {
            //do nothing
        } else if (httpRequest.getMethod().equalsIgnoreCase(OPTIONS_STRING)) {
            httpResponse.setStatus(HttpStatus.SC_OK);
        } else {
            chain.doFilter(request, response);
        }
    }

    @Override
    public void destroy() {
    }

    private boolean validateIsHttps(HttpServletResponse httpServletResponse) {
        String uri = requestInfo.getUri();
        if (isLocalHost(uri) || isSwagger(uri)) {
            return true;
        }
        if (isAcceptHttp() || requestInfo.isHttps()) {
            return true;
        }

        String location = uri.replaceFirst("http", "https");
        httpServletResponse.setStatus(307);
        httpServletResponse.addHeader("location", location);
        return false;
    }

    private boolean isLocalHost(String uri) {
        return (uri.contains("//localhost") || uri.contains("//127.0.0.1"));
    }

    private boolean isSwagger(String uri) {
        return uri.contains("/swagger") || uri.contains("/v2/api-docs") || uri.contains("/configuration/ui") || uri.contains("/webjars/");
    }

    public boolean isAcceptHttp() {
        return this.serviceConfig.getAcceptHttp();
    }
}