/*
 * Copyright 2017-2020, Schlumberger
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opengroup.osdu.register.subscriber.services;

import org.opengroup.osdu.core.common.model.http.AppException;
import org.opengroup.osdu.register.logging.AuditLog;
import org.opengroup.osdu.register.provider.interfaces.subscriber.ISubscriptionRepository;
import org.opengroup.osdu.register.subscriber.model.Secret;
import org.opengroup.osdu.register.subscriber.model.Subscription;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

@Service
public class UpdateSubscriptionSecret {

    @Autowired
    private ISubscriptionRepository subscriptionRepository;
    @Autowired
    private ChallengeResponseCheck challengeResponseCheck;
    @Autowired
    private AuditLog auditLogger;

    public boolean run(Secret input, String subscriptionId) {
        Subscription subscription = subscriptionRepository.get(subscriptionId);
        if (challengeResponseCheck.runUpdate(subscription, input)) {
            if (subscriptionRepository.patch(subscription, input)) {
                auditLogger.updateSubscriptionSecretSuccess(subscriptionId);
                return true;
            }
        } else {
            throw new AppException(400, "Bad Request", "Failed challenge response check to GET " + subscription.getPushEndpoint());
        }
        return false;
    }
}
