/*
 * Copyright 2017-2020, Schlumberger
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opengroup.osdu.register.utils;

import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

@Component
public class AppServiceConfig {

    @Value("${INTEGRATION_TEST_AUDIENCES}")
    private String integrationTestJwtAudiences;
    @Value("${CRON_JOB_EXPECTED_IP}")
    private String cronJobExpectedIp;
    @Value("${ACCEPT_HTTP:false}")
    private boolean acceptHttp;
    @Value("${ENVIRONMENT}")
    private String environment;
    @Value("${PERSISTENCE:CLOUD_NATIVE}")
    private String persistence;
    @Value("${ENTITLEMENTS_API}")
    private String entitlementsApi;
    @Value("${RECORDS_CHANGE_PUBSUB_ENDPOINT}")
    private String recordsChangePubsubEndpoint;
    @Value("${SUBSCRIBER_PRIVATE_KEY_ID}")
    private String subscriberPrivateKeyId;
    @Value("${SUBSCRIBER_SECRET}")
    private String subscriberSecret;

    public String getIntegrationTestJwtAudiences() {
        return integrationTestJwtAudiences;
    }

    public boolean getAcceptHttp() {
        return acceptHttp;
    }

    public String getCronJobExpectedIp() {
        return cronJobExpectedIp;
    }

    public String getEntitlementsApi() {
        return entitlementsApi;
    }

    public String getRecordsChangePubsubEndpoint() {
        return recordsChangePubsubEndpoint;
    }

    public String getSubscriberPrivateKeyId() {
        return subscriberPrivateKeyId;
    }

    public String getSubscriberSecret() {
        return subscriberSecret;
    }

    public boolean isLocalEnvironment() {
        return "LOCAL".equalsIgnoreCase(environment);
    }

    public boolean isPreProd() {
        return isLocalEnvironment() || "DEV".equalsIgnoreCase(environment) ||
                "TEST".equalsIgnoreCase(environment) || "P4D".equalsIgnoreCase(environment);
    }

    public String getMongoDatabaseName() {
        return String.format("ddms-db-%s", getDeploymentEnvironment()).toLowerCase();
    }

    public String getDeploymentEnvironment() {
        return environment.toLowerCase();
    }
}
