/*
 * Copyright 2017-2020, Schlumberger
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opengroup.osdu.register.util;

import com.google.common.base.Strings;

import java.util.Base64;

public class Config {
    public String HostUrl;
    public String securePushUrl;
    public String PushUrl;
    public String OsduTenant;
    public String subscriptionId;
    public String ClientTenant;
    public String SUBSCRIBER_SECRET = System.getProperty("SUBSCRIBER_SECRET", System.getenv("SUBSCRIBER_SECRET"));
    private static Config config = new Config();

    public static Config Instance() {
        String env = System.getProperty("ENVIRONMENT", System.getenv("ENVIRONMENT"));
        config.ClientTenant = getEnvironmentVariableOrDefaultValue("CLIENT_TENANT","nonexistenttenant");
        config.OsduTenant = getEnvironmentVariableOrDefaultValue("OSDU_TENANT","opendes");

        if (env.equalsIgnoreCase("LOCAL")) {
            config.HostUrl = System.getProperty("REGISTER_BASE_URL", System.getenv("REGISTER_BASE_URL"));
            config.securePushUrl= getEnvironmentVariableOrDefaultValue("REGISTER_LOCAL_PUSH_URL","https://localhost:8080/");
            config.subscriptionId = System.getProperty("TEST_SUBSCRIPTION_ID", System.getenv("TEST_SUBSCRIPTION_ID"));
            config.subscriptionId = Base64.getEncoder().encodeToString(("records-changed"+ config.securePushUrl).getBytes());
            config.PushUrl = config.HostUrl;
        } else if (env.equalsIgnoreCase("DEV")) {

            String custom_push_url = System.getProperty("REGISTER_CUSTOM_PUSH_URL1", System.getenv("REGISTER_CUSTOM_PUSH_URL1"));
            config.subscriptionId = getEnvironmentVariableOrDefaultValue("SUBSCRIPTION_ID",
                       genSubscriptionId(custom_push_url));

            config.HostUrl = System.getProperty("REGISTER_BASE_URL", System.getenv("REGISTER_BASE_URL"));
            config.securePushUrl = config.HostUrl;
            config.PushUrl = config.HostUrl;
        }
        return config;
    }

    public boolean isLocalHost() {
        return HostUrl.contains("//localhost");
    }

    private static String getEnvironmentVariableOrDefaultValue(String key, String defaultValue) {
        String environmentVariable = getEnvironmentVariable(key);
        if (environmentVariable == null) {
            environmentVariable = defaultValue;
        }
        return environmentVariable;
    }

    private static String getEnvironmentVariable(String propertyKey) {
        return System.getProperty(propertyKey, System.getenv(propertyKey));
    }

    private static String genSubscriptionId(String custom_push_url)
    {
        return Base64.getEncoder().encodeToString(("records-changed"+ custom_push_url).getBytes());
    }
}
